// Singleton object for work with debug console
Sb.Console = {
	_isEnabled : false,
	_isWindowCreated : false,
	_messages : new Array()
};

Sb.Console.LEVEL_DEBUG   = 'debug';
Sb.Console.LEVEL_INFO    = 'info';
Sb.Console.LEVEL_WARNING = 'warning';
Sb.Console.LEVEL_ERROR   = 'error';

/**
 * Enable debug console
 *
 */
Sb.Console.enable = function() {
	this._isEnabled = true;
	this._createWindow();
	this.log('Debug console was enabled.');
}

/**
 * Write message to console
 *
 * @param string message
 * @param string level
 */
Sb.Console.log = function(message, level) {
	if (!this._isEnabled) {
		return ;
	}
	
	if ('undefined' == typeof level) {
		level = Sb.Console.LEVEL_DEBUG;
	}
	
	var currentDate = new Date();
	
	var message = { 
			date: currentDate.getHours() + ':' + currentDate.getMinutes() + ':' + currentDate.getSeconds() + '.' + currentDate.getMilliseconds(), 
			message: message,
			level: level 
	};
	
	this._messages.push(message);
	
	if ('undefined' != typeof console) {
		console.log('Sb.Console : ' + message.date + ' : ' + message.level + ' : ' + message.message);
	}
	
	if (Element.visible('sbConsoleWindow')) {
		this._updateWindowContent();
	}
}

/**
 * Show debug console
 *
 */
Sb.Console.toggle = function() {
	this._updateWindowContent();
	$('sbConsoleWindow').toggle();
}

/**
 * Update window content with actual messages
 *
 */
Sb.Console._updateWindowContent = function() {
	var windowContentHtml = '<table style="background-color: grey" cellpadding="2" cellspacing="1">' 
		+ '<tr style="background-color: white"><th colspan="3">Debug console</th></tr>'
		+ '<tr style="background-color: white"><th>Time</th><th>Level</th><th>Message</th></tr>';
	
	var messagesHtml = '';
		
	this._messages.each(function(item) {
		messagesHtml = '<tr style="background-color: white">'
			+ '<td>' + item.date + '</td>'
			+ '<td>' + item.level + '</td>'
			+ '<td>' + item.message + '</td></tr>' 
			+ messagesHtml;
	});
	
	windowContentHtml += messagesHtml + '</table>';
	
	$('sbConsoleWindow').update(windowContentHtml);
	
	if ($('sbConsoleWindow').getHeight() > 500) {
		$('sbConsoleWindow').setStyle({ height: '500px' });
	}
}

/**
 * Create console window
 *
 */
Sb.Console._createWindow = function() {
	Insertion.Top(document.body, '<div id="sbConsoleLink" style="display:none" onclick="Sb.Console.toggle();">X</div><div id="sbConsoleWindow" style="display:none" onclick="Sb.Console.toggle();"></div>');
	
	$('sbConsoleLink').setStyle({
		display: 'block',
		position: 'absolute',
		color: 'silver',
		cursor: 'pointer'
	});
	
	$('sbConsoleWindow').setStyle({
		position: 'absolute',
		backgroundColor: 'white',
		color: 'black',
		border: '1px solid black',
		padding: '5px',
		cursor: 'pointer',
		left: '10px',
		top: '10px',
		overflowY: 'auto'
	});
	
	this._isWindowCreated = true;
}